# 📘 MediaWiki Appliance

**An Open Source Appliance from Robbie Ferguson**
(c) 2025 Robbie Ferguson. Licensed under the Apache License, Version 2.0

A ready-to-use MediaWiki appliance built for simplicity, performance, and security. This installer prepares a clean Debian system to serve MediaWiki at the root path with modern defaults, file uploads enabled, Redis caching, self-signed HTTPS, and preloaded core extensions.

---

## ⚙️ How It Works

The appliance is built by running `installer.sh` on a clean Debian instance. It installs all required packages, downloads the latest stable version of MediaWiki, sets up MariaDB and Redis, configures NGINX with HTTPS, and preloads useful skins and extensions.

After installation, the wiki is fully functional at:

```
https://your-server-ip/
```

---

## 🧪 First-Time Setup

After installation, log into your wiki as:

- **Username**: `admin`
- **Password**: `changeme`

> 🔒 You must change this password immediately!

Visit:
```
https://your-server-ip/activate/
```
This setup screen allows you to securely define a new password. It is a **one-time activation process**.

---

## 📂 What’s Included

- MediaWiki (latest stable)
- Skins: Vector (default), MonoBook, Timeless
- Extensions:
  - Cite
  - WikiEditor
  - SyntaxHighlight_GeSHi
  - CategoryTree
- File uploads enabled
- Redis server with MediaWiki cache integration
- PHP tuned for media uploads
- Self-signed HTTPS certificate for secure local access

---

## 🔧 Enabling Let’s Encrypt (Optional)

The appliance includes **Certbot** and is preconfigured for HTTPS. If you plan to serve your wiki publicly with a real domain name:

1. Update `/etc/nginx/sites-available/mediawiki` to use your actual `server_name`
2. Then run:
   ```bash
   certbot --nginx -d your.domain.name
   ```

This will obtain a valid SSL certificate and reload NGINX.

---

## 🔁 Reinstalling or Removing

If the installer fails and you need to revert in order to try again, you can purge the appliance from your system:

```bash
./installer.sh --purge
```

This will:
- Stop all related services
- Remove MediaWiki files and NGINX config
- Uninstall MariaDB, PHP, Redis, and Certbot
- Leave the system clean for a rebuild

Note: This process assumes you are running the script on a dedicated appliance. Running this on anything but a dedicated appliance may destroy your system.

---

## 🔐 Backup Tips

To ensure your wiki can be restored, back up:

1. The database:
   ```bash
   mysqldump -u root mediawiki > mediawiki.sql
   ```

2. The uploaded files and configs:
   ```bash
   tar czf uploads_backup.tar.gz /var/www/html/images /var/www/html/LocalSettings.php
   ```

---

## 💬 Support

This appliance was built by Robbie Ferguson to provide a turn-key, modern MediaWiki experience. Contributions, forks, and enhancements are welcome.
